@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,8 +9,7 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KLocalizedString>
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
 #endif
 #include <QApplication>
@@ -18,13 +17,15 @@
 
 int main(int argc, char **argv)
 {
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     QApplication app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     app.setDesktopFileName(QStringLiteral("org.kde.contactthemeeditor"));
 
     KCrash::initialize();
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("contactthemeeditor"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("contactthemeeditorrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("contactthemeeditorui.rc"));
@@ -36,7 +37,7 @@ int main(int argc, char **argv)
                          QStringLiteral(GRANTLEEEDITOR_VERSION),
                          i18n("Contact Theme Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2013-2021 contactthemeeditor authors"));
+                         i18n("Copyright © 2013-%1 contactthemeeditor authors", QStringLiteral("2022")));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kaddressbook")));
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
@@ -52,7 +53,7 @@ int main(int argc, char **argv)
 
     KDBusService service;
 
-    ContactEditorMainWindow *mw = new ContactEditorMainWindow();
+    auto mw = new ContactEditorMainWindow();
     mw->show();
     const int ret = app.exec();
     return ret;
